#!/usr/bin/env node
"use strict";
const co = require('co');
const SkylarQ_1 = require('./src/SkylarQ');
const ProgressBar = require('progress');
const program = require('commander');
const fs = require('fs-extra');
const barSetting = { total: 33 };
const bar = new ProgressBar('[:bar] :current/:total :percent :elapseds :etas', barSetting);
const HOME_DIR = process.env[(process.platform === 'win32') ? 'USERPROFILE' : 'HOME'];
const ORG_SETTING_FILE_PATH = './skylarq.yml';
const DEFAULT_SETTING_FILE_PATH = HOME_DIR + '/skylarq.yml';
const cli = program
    .version('0.0.2')
    .option('-b, --browser', 'show browser')
    .option('--i-agree-terms', `Express agreement to the terms.(You must read terms and specify this flag before using skylarq. If you don't read yet or can't agree the terms, don't use this flag.)`, false)
    .option('--init', 'create setting file to home directory')
    .option('-f, --file-path [path]', 'specify config file path', DEFAULT_SETTING_FILE_PATH)
    .parse(process.argv);
if (cli.init) {
    try {
        fs.copySync(ORG_SETTING_FILE_PATH, DEFAULT_SETTING_FILE_PATH, { clobber: false });
        console.log(`setting file is created to ${DEFAULT_SETTING_FILE_PATH}`);
        process.exit(0);
    }
    catch (e) {
        console.log(`${DEFAULT_SETTING_FILE_PATH} is already exist`);
        process.exit(1);
    }
}
if (!cli.iAgreeTerms) {
    console.log('Before start skylarq, you must read terms and specify --i-agree-terms flag if you can agree.');
    process.exit(0);
}
co(function* () {
    // filePath have default value(DEFAULT_SETTING_FILE_PATH), so ignore null check.
    const skylarq = new SkylarQ_1.SkylarQ(cli.filePath, cli.browser);
    yield skylarq.insertCode();
    yield skylarq.agreeTerms();
    while (true) {
        yield skylarq.waitForNextQuestionOrCouponCode();
        if (yield skylarq.hasCouponCode()) {
            break;
        }
        yield skylarq.answerQuestions();
        let remainQuestionNum = yield skylarq.extractRemainQuestionNum();
        bar.update((barSetting.total - remainQuestionNum) / barSetting.total);
        yield skylarq.nextPage();
    }
    const couponCode = yield skylarq.getCouponCode();
    console.log('coupon code: ' + couponCode);
    yield skylarq.end();
});
//# sourceMappingURL=index.js.map